numpy.polynomial.Polynomial
===========================

.. currentmodule:: numpy.polynomial

.. autoclass:: Polynomial

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Polynomial.__init__
         Polynomial.convert
         Polynomial.copy
         Polynomial.cutdeg
         Polynomial.degree
         Polynomial.deriv
         Polynomial.has_samecoef
         Polynomial.has_samedomain
         Polynomial.has_samewindow
         Polynomial.integ
         Polynomial.linspace
         Polynomial.mapparms
         Polynomial.roots
         Polynomial.trim
         Polynomial.truncate



   

